@@ -95,7 +95,9 @@ void eraAtioq(double ri, double di, eraASTROM *astrom,
 **     eraC2s       p-vector to spherical
 **     eraAnp       normalize angle into range 0 to 2pi
 **
-**  Copyright (C) 2013-2017, NumFOCUS Foundation.
+**  This revision:   2020 December 7
+**
+**  Copyright (C) 2013-2021, NumFOCUS Foundation.
 **  Derived, with permission, from the SOFA library.  See notes at end of file.
 */
 {
@@ -103,9 +105,9 @@ void eraAtioq(double ri, double di, eraASTROM *astrom,
    const double CELMIN = 1e-6;
    const double SELMIN = 0.05;
 
-   double v[3], x, y, z, xhd, yhd, zhd, f, xhdt, yhdt, zhdt,
-          xaet, yaet, zaet, azobs, r, tz, w, del, cosdel,
-          xaeo, yaeo, zaeo, zdobs, hmobs, dcobs, raobs;
+   double v[3], x, y, z, sx, cx, sy, cy, xhd, yhd, zhd, f,
+          xhdt, yhdt, zhdt, xaet, yaet, zaet, azobs, r, tz, w, del,
+          cosdel, xaeo, yaeo, zaeo, zdobs, hmobs, dcobs, raobs;
 
 
 /* CIRS RA,Dec to Cartesian -HA,Dec. */
@@ -115,9 +117,13 @@ void eraAtioq(double ri, double di, eraASTROM *astrom,
    z = v[2];
 
 /* Polar motion. */
-   xhd = x + astrom->xpl*z;
-   yhd = y - astrom->ypl*z;
-   zhd = z - astrom->xpl*x + astrom->ypl*y;
+   sx = sin(astrom->xpl);
+   cx = cos(astrom->xpl);
+   sy = sin(astrom->ypl);
+   cy = cos(astrom->ypl);
+   xhd = cx*x + sx*z;
+   yhd = sx*sy*x + cy*y - cx*sy*z;
+   zhd = -sx*cy*x + sy*y + cx*cy*z;
 
 /* Diurnal aberration. */
    f = ( 1.0 - astrom->diurab*yhd );
@@ -182,7 +188,7 @@ void eraAtioq(double ri, double di, eraASTROM *astrom,
 /*----------------------------------------------------------------------
 **  
 **  
-**  Copyright (C) 2013-2017, NumFOCUS Foundation.
+**  Copyright (C) 2013-2021, NumFOCUS Foundation.
 **  All rights reserved.
 **  
 **  This library is derived, with permission, from the International
