@@ -47,7 +47,9 @@ int eraTcbtdb(double tcb1, double tcb2, double *tdb1, double *tdb2)
 **
 **     IAU 2006 Resolution B3
 **
-**  Copyright (C) 2013-2015, NumFOCUS Foundation.
+**  This revision:  2019 June 20
+**
+**  Copyright (C) 2013-2021, NumFOCUS Foundation.
 **  Derived, with permission, from the SOFA library.  See notes at end of file.
 */
 {
@@ -61,8 +63,9 @@ int eraTcbtdb(double tcb1, double tcb2, double *tdb1, double *tdb2)
 
    double d;
 
+
 /* Result, safeguarding precision. */
-   if ( tcb1 > tcb2 ) {
+   if ( fabs(tcb1) > fabs(tcb2) ) {
       d = tcb1 - t77td;
       *tdb1 = tcb1;
       *tdb2 = tcb2 + tdb0 - ( d + ( tcb2 - t77tf ) ) * ERFA_ELB;
@@ -79,7 +82,7 @@ int eraTcbtdb(double tcb1, double tcb2, double *tdb1, double *tdb2)
 /*----------------------------------------------------------------------
 **  
 **  
-**  Copyright (C) 2013-2015, NumFOCUS Foundation.
+**  Copyright (C) 2013-2021, NumFOCUS Foundation.
 **  All rights reserved.
 **  
 **  This library is derived, with permission, from the International
